@@ -88,6 +88,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
     private TextView mEmptyView;
     private final ContextMenuRecyclerView[] mLists = new ContextMenuRecyclerView[MODE_TOTAL];
     private FastScroller mFastScroller;
+    private SharedPreferences mSettings;
 
     private static final int REFRESH = 101;
     private static final int UPDATE_LIST = 102;
@@ -107,6 +108,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
     public void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
         final Resources res = getResources();
+        mSettings = PreferenceManager.getDefaultSharedPreferences(getActivity());
         mSongsAdapter = new AudioBrowserAdapter(MediaLibraryItem.TYPE_MEDIA, this, true, res);
         mArtistsAdapter = new AudioBrowserAdapter(MediaLibraryItem.TYPE_ARTIST, this, true, res);
         mAlbumsAdapter = new AudioBrowserAdapter(MediaLibraryItem.TYPE_ALBUM, this, true, res);
@@ -253,7 +255,6 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         final MediaLibraryItem mediaItem = adapter.getItem(position);
 
         if (id == R.id.audio_list_browser_delete) {
-            if (mediaItem.getItemType() != MediaLibraryItem.TYPE_MEDIA) return false;
             final MediaLibraryItem previous = position > 0 ? adapter.getItem(position-1) : null;
             final MediaLibraryItem next = position < adapter.getItemCount()-1 ? adapter.getItem(position+1) : null;
             final String message;
@@ -265,7 +266,14 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
             else adapter.remove(mediaItem);
 
             if (mode == MODE_PLAYLIST) {
-                cancel = null;
+                if (mediaItem.getItemType() != MediaLibraryItem.TYPE_PLAYLIST) return false;
+                cancel = new Runnable() {
+                    @Override
+                    public void run() {
+                        if (separator != null) adapter.addItems(separator, mediaItem);
+                        else adapter.addItems(mediaItem);
+                    }
+                };
                 message = getString(R.string.playlist_deleted);
                 action = new Runnable() {
                     @Override
@@ -274,6 +282,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
                     }
                 };
             } else if (mode == MODE_SONG) {
+                if (mediaItem.getItemType() != MediaLibraryItem.TYPE_MEDIA) return false;
                 message = getString(R.string.file_deleted);
                 cancel = new Runnable() {
                     @Override
@@ -435,7 +444,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
     public void onTabSelected(TabLayout.Tab tab) {
         getActivity().supportInvalidateOptionsMenu();
         mFastScroller.setRecyclerView(mLists[tab.getPosition()]);
-        VLCApplication.getSettings().edit().putInt(Constants.KEY_AUDIO_CURRENT_TAB, tab.getPosition()).apply();
+        mSettings.edit().putInt(Constants.KEY_AUDIO_CURRENT_TAB, tab.getPosition()).apply();
     }
 
     @Override
@@ -607,7 +616,7 @@ public class AudioBrowserFragment extends BaseAudioBrowser implements SwipeRefre
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
-                final List<MediaLibraryItem> artists = Util.arrayToMediaArrayList(mMediaLibrary.getArtists(VLCApplication.getSettings().getBoolean(Constants.KEY_ARTISTS_SHOW_ALL, false)));
+                final List<MediaLibraryItem> artists = Util.arrayToMediaArrayList(mMediaLibrary.getArtists(mSettings.getBoolean(Constants.KEY_ARTISTS_SHOW_ALL, false)));
                 VLCApplication.runOnMainThread(new Runnable() {
                     @Override
                     public void run() {
